summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/iremga20.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/iremga20.cpp')
-rw-r--r--src/devices/sound/iremga20.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/devices/sound/iremga20.cpp b/src/devices/sound/iremga20.cpp
index 041ec44241e..ba49eaa75c4 100644
--- a/src/devices/sound/iremga20.cpp
+++ b/src/devices/sound/iremga20.cpp
@@ -73,7 +73,7 @@ iremga20_device::iremga20_device(const machine_config &mconfig, const char *tag,
void iremga20_device::device_start()
{
- m_stream = stream_alloc(0, 2, clock()/4);
+ m_stream = stream_alloc_legacy(0, 2, clock()/4);
save_item(NAME(m_regs));
for (int i = 0; i < 4; i++)
@@ -126,10 +126,10 @@ void iremga20_device::rom_bank_updated()
}
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void iremga20_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void iremga20_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
stream_sample_t *outL, *outR;
@@ -126,10 +126,10 @@ void iremga20_device::rom_bank_updated()
}
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------